package de.intevation.artifactdatabase.rest;

import org.restlet.resource.Get;  
import org.restlet.resource.Post;  
import org.restlet.resource.ServerResource;

import org.restlet.representation.Representation;
import org.restlet.representation.EmptyRepresentation;

import org.restlet.ext.xml.DomRepresentation;

import de.intevation.artifacts.ArtifactDatabase;
import de.intevation.artifacts.Artifact;

import org.restlet.data.Request;
import org.restlet.data.Response;
import org.restlet.data.Status;

import org.restlet.data.MediaType;

import org.apache.log4j.Logger;

import org.w3c.dom.Document;

/**
 * @author Sascha L. Teichmann (sascha.teichmann@intevation)
 */
public class ArtifactResource
extends      ServerResource
{
    private static Logger logger = Logger.getLogger(ArtifactResource.class);

    public static final String PATH = "/artifact/{uuid}";

    public static final String NO_ARTIFACT_FOUND = "Artifact not found";

    @Get
    public Representation represent() {

        Request request = getRequest();

        String identifier = (String)request.getAttributes().get("uuid");

        if (logger.isDebugEnabled()) {
            logger.debug("looking for artifact id '" + identifier + "'");
        }

        ArtifactDatabase db = (ArtifactDatabase)getContext()
            .getAttributes().get("database");

        Artifact artifact = db.getArtifact(identifier);

        if (artifact == null) {
            Response response = getResponse();
            response.setStatus(Status.CLIENT_ERROR_NOT_FOUND, NO_ARTIFACT_FOUND);
            return new EmptyRepresentation();
        }

        Document description = artifact.describe(db.getArtifactContext());

        if (logger.isDebugEnabled()) {
            logger.debug("out document: " + description);
        }

        return new DomRepresentation(
            MediaType.APPLICATION_XML, description);
    }

    /*
    @Post
    public Representation representPost() {
        return new EmptyRepresentation();
    }
    */
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8:
